/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: Form.java,v 1.4.2.3 2000/04/03 07:38:17 pmahar Exp $
 */

package org.enhydra.kelp.sample.presentation;

import org.enhydra.kelp.sample.KelpSample;
import com.lutris.xml.xmlc.*;
import com.lutris.xml.xmlc.html.*;
import org.w3c.dom.*;
import org.w3c.dom.html.*;
import com.lutris.appserver.server.httpPresentation.*;
import java.util.*;
import java.io.*;

/**
 * <p>
 * This presentation object dynamically creates an HTML page
 * showing the greeting from the application configuration file.
 * </p>
 */
public class Form implements HttpPresentation {
  private String     dataFilename = null;
  private Properties data         = null;
  private FormHTML   page         = null;
  private HttpPresentationComms comms;

 /**
   * Process the Catalog page to see what the shopper wants
   * to do with the selected product. From this page they
   * can register and for each product they can get information,
   * download, or purchase.
   *
   * @param comms
   *   HTTP communications object.
   * @exception Exception
   *   Any exception may be thrown.
   */
  public void run(HttpPresentationComms c)
        throws HttpPresentationException {
    comms = c;
    initData();
    saveParameters();
    page = createPage();
    comms.response.writeHTML(page.toDocument());
  }

  private void saveParameters() {
    String paramFirst = null;
    String paramLast = null;
    try {
      paramFirst = comms.request.getParameter("first");
      paramLast =  comms.request.getParameter("last");
    } catch (Exception e) {
      paramFirst = null;
      paramLast  = null;
    }
    if (paramFirst != null && paramLast != null) {
      data.put("first", paramFirst);
      data.put("last", paramLast);
      writePropertyFile();
    }
  }

  public FormHTML createPage()  {
    page = new FormHTML();
    fixupForm();
    return page;
  }

  private void fixupForm() {
    String first = (String) data.get("first");
    String last  = (String) data.get("last");
    HTMLInputElement inputFirst = page.getElementFirst();
    HTMLInputElement inputLast  = page.getElementLast();
    inputFirst.setValue(first);
    inputLast.setValue(last);
  }


  private void writePropertyFile() {
    FileOutputStream out;
    try {
      out = new FileOutputStream(dataFilename, false);
      data.save(out, "Data for Form page");
      out.close();
    } catch (java.io.IOException e) {
      e.printStackTrace();
    }
  }

  private void readPropertyFile() {
    FileInputStream is = null;
    try {
      is = new FileInputStream(dataFilename);
      data = new Properties();
      data.load(is);
      is.close();
    } catch (Exception e) {
      // create deault
      data = new Properties();
      data.put("first","Luke");
      data.put("last","Skywalker");
    }
  }

  private void initData() {
    KelpSample app = (KelpSample) comms.application;
    dataFilename = app.getAppRoot() + File.separator +
       "data" + File.separator + "formdata.properties";

    try {
      data = (Properties) comms.sessionData.get("data");
    } catch (com.lutris.util.KeywordValueException e) {
      data = null;
    }
    if (data == null) {
      readPropertyFile();
    }
  }
}


