/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: AboutBox.java,v 1.1.2.2 2000/04/01 00:14:27 pmahar Exp $
 */

package org.enhydra.devsys.swing;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JDialog;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextArea;
import javax.swing.SwingConstants;


import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;

import java.awt.AWTEvent;
import java.awt.Dialog;
import java.awt.Dimension;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Frame;
import java.awt.Point;
import java.awt.SystemColor;
import java.beans.Beans;

public class AboutBox extends JDialog {
  private JPanel panelMain;
  private JPanel panelButton;
  private JPanel panelLabel;
  private JLabel labelTitle;
  private JTextArea textArea;
  private JLabel labelSmall;
  private JButton buttonOK;
  private GridBagLayout layoutMain;
  private GridBagLayout layoutButton;
  private GridBagLayout layoutLabel;

  private boolean standalone = false;
  private LocalActionListener actionListener = null;

  public AboutBox(Frame owner) {
    super(owner, null, true);
    construct();
  }

  public AboutBox(Dialog owner) {
    super(SwingUtil.getDialogOwner(owner), null, true);
    construct();
  }

  private void construct() {
    try  {
      jbInit();
      pmInit();
      pack();
      setResizable(true);
    }
    catch (Exception e) {
      e.printStackTrace();
    }
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
  }

  ///
  protected void clearAll() {
    buttonOK.removeAll();
    buttonOK.removeActionListener(actionListener);
    labelTitle.removeAll();
    textArea.removeAll();
    labelSmall.removeAll();
    panelButton.removeAll();
    panelLabel.removeAll();
    panelMain.removeAll();
    removeAll();
    getContentPane().removeAll();
    actionListener = null;
    buttonOK       = null;
    labelSmall   = null;
    layoutButton   = null;
    layoutLabel    = null;
    layoutMain     = null;
    panelButton    = null;
    panelLabel     = null;
    panelMain      = null;
    setTitle(null);
  }

  ///
  public void show() {
    Point centeringPoint;
    pack();
    centeringPoint = SwingUtil.getCenteringPoint(getSize());
    setLocation(centeringPoint);
    buttonOK.requestFocus();
    super.show();
  }

  public void actionPerformed(ActionEvent e) {
    if (e.getSource() == buttonOK) {
      closeDialog();
    }
  }

  public static void main(String[] args) {
    SwingUtil.setLookAndFeelToSystem();
    AboutBox dlg;
    dlg = new AboutBox(new Frame());
    dlg.standalone = true;
    dlg.show();
  }

  public String getTitleText() {
    return labelTitle.getText();
  }

  public String getTextAreaText() {
    return textArea.getText();
  }


  public void setTitleText(String p) {
    labelTitle.setText(p);
    setTitle("About " + p);
  }

  public void setTextAreaText(String s) {
    textArea.setText(s);
  }


  public String getSmallText() {
    return labelSmall.getText();
  }

  public void setSmallText(String v) {
    labelSmall.setText(v);
  }
  ///
  ///

  protected void processWindowEvent(WindowEvent e) {
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      closeDialog();
    }
    super.processWindowEvent(e);
  }

  protected void disposeDialog() {
    setVisible(false);
    removeAll();
    dispose();
  }

  ///
  ///

  private void closeDialog() {
    disposeDialog();
    if (standalone) {
      System.exit(0);
    }
  }

  private void pmInit() {
    actionListener = new LocalActionListener();
    buttonOK.addActionListener(actionListener);
  }

  private void jbInit() throws Exception  {
    panelMain   = (JPanel) Beans.instantiate(getClass().getClassLoader(), JPanel.class.getName());
    panelLabel  = (JPanel) Beans.instantiate(getClass().getClassLoader(), JPanel.class.getName());
    panelButton = (JPanel) Beans.instantiate(getClass().getClassLoader(), JPanel.class.getName());
    labelTitle    = (JLabel) Beans.instantiate(getClass().getClassLoader(), JLabel.class.getName());
    textArea  = (JTextArea) Beans.instantiate(getClass().getClassLoader(), JTextArea.class.getName());
    labelSmall   = (JLabel) Beans.instantiate(getClass().getClassLoader(), JLabel.class.getName());
    buttonOK       = (JButton) Beans.instantiate(getClass().getClassLoader(), JButton.class.getName());
    layoutMain   = (GridBagLayout) Beans.instantiate(getClass().getClassLoader(), GridBagLayout.class.getName());
    layoutButton = (GridBagLayout) Beans.instantiate(getClass().getClassLoader(), GridBagLayout.class.getName());
    layoutLabel  = (GridBagLayout) Beans.instantiate(getClass().getClassLoader(), GridBagLayout.class.getName());

    buttonOK.setText("OK");
    buttonOK.setMaximumSize(new Dimension(100, 30));
    buttonOK.setMinimumSize(new Dimension(60, 15));
    buttonOK.setPreferredSize(new Dimension(75, 20));
    buttonOK.setMargin(new Insets(2, 12, 2, 12));
    buttonOK.setMnemonic('0');

    panelLabel.setLayout(layoutLabel);
    labelTitle.setBackground(SystemColor.controlLtHighlight);
    labelTitle.setFont(new java.awt.Font("Dialog", 3, 18));
    labelTitle.setForeground(SystemColor.infoText);
    labelTitle.setToolTipText("");
    labelTitle.setText("Primary");
    textArea.setFont(new java.awt.Font("Dialog", 0, 16));
    textArea.setDisabledTextColor(SystemColor.infoText);
    textArea.setBackground(SystemColor.controlLtHighlight);
    textArea.setEnabled(false);
    textArea.setText("Text Area");
    textArea.setForeground(SystemColor.infoText);
    textArea.setEditable(false);
    labelSmall.setBackground(SystemColor.controlLtHighlight);
    labelSmall.setForeground(SystemColor.infoText);
    labelSmall.setMaximumSize(new Dimension(200, 17));
    labelSmall.setText("Version");
    panelLabel.setBackground(SystemColor.controlLtHighlight);
    panelLabel.setBorder(BorderFactory.createLoweredBevelBorder());
    panelLabel.add(labelTitle, new GridBagConstraintsX(0, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraintsX.CENTER, GridBagConstraintsX.BOTH, new Insets(10, 10, 5, 10), 40, 0));
    panelLabel.add(textArea, new GridBagConstraintsX(0, 1, 1, 1, 0.5, 0.5
            ,GridBagConstraintsX.CENTER, GridBagConstraintsX.BOTH, new Insets(5, 10, 5, 10), 40, 0));
    panelLabel.add(labelSmall, new GridBagConstraintsX(0, 2, 1, 1, 0.0, 0.0
            ,GridBagConstraintsX.WEST, GridBagConstraintsX.HORIZONTAL, new Insets(5, 10, 10, 10), 40, 0));

    panelButton.setLayout(layoutButton);
    panelButton.add(buttonOK, new GridBagConstraintsX(0, 0, 1, 1, 0.5, 0.5
            ,GridBagConstraintsX.CENTER, GridBagConstraintsX.NONE, new Insets(5, 0, 10, 0), 0, 11));

    panelMain.setLayout(layoutMain);
    panelMain.setMaximumSize(new Dimension(500, 400));
    panelMain.setMinimumSize(new Dimension(300, 150));
    panelMain.setPreferredSize(new Dimension(450, 250));
    panelMain.add(panelLabel, new GridBagConstraintsX(0, 1, 1, 1, 0.1, 0.1
            ,GridBagConstraintsX.CENTER, GridBagConstraintsX.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    panelMain.add(panelButton, new GridBagConstraintsX(0, 2, 1, 1, 0.1, 0.1
            ,GridBagConstraintsX.CENTER, GridBagConstraintsX.BOTH, new Insets(0, 0, 0, 0), 0, 0));

    this.getContentPane().add(panelMain);
  }


  class LocalActionListener implements ActionListener {
    public void actionPerformed(ActionEvent event) {
      closeDialog();
    }
  }
}


