/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: PropUtil.java,v 1.2.2.6 2000/04/06 02:53:32 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.common;

import org.enhydra.ide.jbuilder.common.node.OtterNode;

import java.util.Vector;
import java.io.File;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class PropUtil {

    /**
     * Constructor declaration
     *
     *
     * @see
     */
    public PropUtil() {}

    /**
     * Method declaration
     *
     *
     * @param s
     * @param def
     *
     * @return
     *
     * @see
     */
    public static int stringToInt(String s, int def) {
	int i = def;

	if (s != null) {
	    if (s.trim().length() > 0) {
               try {
                i = Integer.parseInt(s.trim());
               } catch (Exception e) {
                 i = def;
               }
	    }
	}

	return i;
    }

    public static String booleanToString(boolean b) {
      String flag = b ? "true" : "false";
      return flag;
    }

    public static boolean stringToBoolean(String s, boolean def) {
	boolean b = def;

	if (s != null) {
	    if (s.trim().length() > 0) {
		b = s.trim().equalsIgnoreCase("true");
	    }
	}

	return b;
    }

    public static String[][] getArrayProperty(OtterNode node,
                                              String lengthName,
                                              String columnName1,
                                              String columnName2) {
	String[][] array        = new String[0][0];
	String     columnValue1 = null;
	String     columnValue2 = null;
	Vector     valueVector  = new Vector();
        int        length       = 0;

        length = stringToInt(node.getProperty(lengthName),100);

	for (int i = 0; i < length; i++) {
	    columnValue1 = node.getProperty(columnName1 + "." + i);
	    columnValue2 = node.getProperty(columnName2 + "." + i);

	    if (columnValue1 != null && columnValue2 != null) {
		if (columnValue1.trim().length() > 0 && columnValue2.trim().length() > 0) {
                    // note: new 'row' object is needed for each call to addElement
		    String[] row = new String[2];
		    row[0] = columnValue1;
		    row[1] = columnValue2;
		    valueVector.addElement(row);
		}
	    }
	}

	length = valueVector.size();
        node.setProperty(lengthName, length); // update to valid length

        String[] row = new String[2];

	array = new String[length][2];

	for (int i = 0; i < length; i++) {
	    row = (String[]) valueVector.elementAt(i);
	    array[i][0] = row[0];
	    array[i][1] = row[1];
        }

	return array;
    }

    /**
     * Method declaration
     *
     *
     * @param map
     *
     * @see
     */
    public static void putArrayProperty(OtterNode node,
                                        String lengthName,
                                        String columnName1,
                                        String columnName2,
                                        String[][] array) {
	int    rawLength = 0;
        int    newLength = 0;
	String columnValue1 = new String();
	String columnValue2 = new String();

        rawLength = stringToInt(node.getProperty(lengthName),100);
	for (int i = 0; i < rawLength; i++) {
	    node.setProperty(columnName1 + "." + i, null);
	    node.setProperty(columnName2 + "." + i, null);
	}

        rawLength = array.length;
	for (int i = 0; i < rawLength; i++) {
	    columnValue1 = array[i][0];
	    columnValue2 = array[i][1];

	    if (columnValue1.trim().length() > 0 &&
                columnValue2.trim().length() > 0) {
		node.setProperty(columnName1 + "." + newLength, columnValue1);
		node.setProperty(columnName2 + "." + newLength, columnValue2);
                newLength++;
	    }
	}

        node.setProperty(lengthName, newLength); // update to valid length

    }

    public static void putFileRelativeToProject(OtterNode node,
       String propertyName, String inFilename) {

      String outFilename = compressPathRelativeToProject(node, inFilename);
      node.setProperty(propertyName, outFilename);
   }


    public static File getFileRelativeToProject(OtterNode node,
                  String propertyName) {
      File file = null;
      String filename = node.getProperty(propertyName);
      if (filename != null) {
         filename = PropUtil.expandPathRelativeToProject(node, filename);
         file = new File(filename);
      }
      return file;
    }

    public static String compressPathRelativeToProject(OtterNode node,
       String inPath) {
      String outPath      = inPath;
      String absolutePath = null;
      if (! inPath.startsWith(".")) {
         File file = new File(node.getProject().getFilename());
         String projectParent = file.getParent();
         file = new File(inPath);
         absolutePath = file.getAbsolutePath().trim();
         if (absolutePath.length() > inPath.trim().length()) {
             // Not a valid path.
         } else {
             outPath = absolutePath;
             if (outPath.startsWith(projectParent)) {
               outPath = "." + File.separator +
                  outPath.substring(projectParent.length()+1);
             }
         }
      }
      return outPath;
    }

    public static String expandPathRelativeToProject(OtterNode node,
         String inPath) {
      String outPath = inPath;
      if (inPath.startsWith(".")) {
        // expand path relative to the project.
        File file = new File(node.getProject().getFilename());
        outPath = file.getParent() +
                  File.separator + inPath.substring(2);
      }
      return outPath;
    }




}

