/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: ConfBuildThread.java,v 1.1.2.11 2000/04/06 23:56:34 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.common.wizard.conf;


import org.enhydra.ide.KelpVersion;
import org.enhydra.ide.jbuilder.common.FileUtil;
import org.enhydra.ide.jbuilder.common.PropUtil;
import org.enhydra.ide.jbuilder.common.wizard.AbstractBuildThread;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import org.enhydra.ide.jbuilder.common.node.OtterNodeFactory;
import org.enhydra.ide.jbuilder.common.node.OtterFolderNode;
import org.enhydra.ide.jbuilder.common.node.OtterConfFileNode;
import org.enhydra.ide.jbuilder.common.capture.Writer;
import org.enhydra.ide.jbuilder.common.capture.WriteListener;


import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.PrintWriter;

/**
 * CompileThread calls XMLC once for each selected HTML file.
 *
 *
 * @author
 * Paul Mahar
 * @version %I%, %G%
 */
public class ConfBuildThread extends AbstractBuildThread {
    private File startMultiServerDirectory = null;


    public ConfBuildThread() {
      super();
    }

    public void setStartMultiServerDirectory(File d) {
      startMultiServerDirectory = d;
    }

    public File getStartMultiServerDirectory() {
      return startMultiServerDirectory;
    }

    /**
     *
     * @param listeners
     */
    public ConfBuildThread(WriteListener[] listeners) {
       super(listeners);
    }

    public ConfBuildThread(WriteListener[] listeners,
                         boolean buffer) {
        super(listeners, buffer);
    }

    /**
     * Loop through all selected conf.in files and copy them
     * to the output directory and do a search and replace using
     * the project conf table.  Write out exceptions to any
     * registered listeners.
     */
    public void make() {
      if (getProject().isConfStartupSelected()) {
        makeStartup();
      }
      if (getNodes().length > 0) {
        makeSelected();
      }
    }


    private void makeStartup() {
      if (getProject().isConfStartupJava()) {
        OtterNodeFactory factory = null;
        StartMultiServer start   = null;
        factory = getProject().getNodeFactory();
        start   = new StartMultiServer(getProject());
        start.setDirectory(getStartMultiServerDirectory());
        try {
          start.create();
          factory.createJavaFileNode(
             getProject(), getProject(), start.getFile().getAbsolutePath());
          getTraceWriter().println("Creating startup class: ");
          getTraceWriter().println("   " + start.getFile().getAbsolutePath());
        } catch (java.io.IOException e) {
          e.printStackTrace();
        }
      }
      if (getProject().isConfStartupRun()) {
        getProject().configureRunClass();
      }
      getTraceWriter().println("--- startup configuration complete ---");
    }

    private void makeSelected() {
	int	   count = getNodes().length;

	for (int i = 0; i < count; i++) {
            OtterConfFileNode confNode = (OtterConfFileNode) getNodes()[i];
	    if (!isFresh()) {
		break;
	    }

	    try {
		if (confNode.isSelected() && isFresh()) {
                    File sourceDoc = new File(confNode.getFilename());
                    if (sourceDoc.exists()){
                       if (isPrintProgress()) {
     		          getTraceWriter().println("Processing ");
		          getTraceWriter().println("  "
                            + sourceDoc.getAbsolutePath());
                       }
                       processNode(confNode);
                    } else {
                      if (isPrintProgress()) {
                        getTraceWriter().println("Source document not found: " +
                          sourceDoc.getAbsolutePath());
                      }
                    }
		}
	    } catch (Exception e) {
		e.printStackTrace();
                if (isPrintProgress()) {
  		  getTraceWriter().println("");
                }
	    }
	}

	if (isFresh()) {
          if (isPrintProgress()) {
            printResults();
          }
          printExceptions();
          addNodesToProject();
          if (isPrintProgress()) {
            getTraceWriter().println("");
	    getTraceWriter().println("--- conf processing complete ---");
	    getTraceWriter().println("");
          }

	} else {
            printExceptions();
	    getTraceWriter().println("");
	    getTraceWriter().println("--- Processing interrupted ---");
     	    getTraceWriter().println("");
	}

    }

    /**
     * Determine what files were created and write out the
     * compilation results to any registered listeners.
     */
    public void printResults() {
	int eCount = 0;
        int totalCount = getNodes().length;
        int selectCount = 0;

	getTraceWriter().println("");
	getTraceWriter().println("Gathering results...");

	for (int i = 0; i < totalCount; i++) {
	    if (getNodes()[i].isSelected() &&
                getNodes()[i].getException() != null) {
		eCount++;
	    }
	}

	sleepInSeconds(0.1);

	for (int i = 0; i < totalCount; i++) {
	  if (getNodes()[i].isSelected()) {
	    selectCount++;
          }
        }


	if ( eCount < selectCount ) {
	    getTraceWriter().println("");
	    getTraceWriter().println("New conf files:");

	    for (int i = 0; i < totalCount; i++) {
                OtterConfFileNode confNode = (OtterConfFileNode) getNodes()[i];
		sleepInSeconds(0.1);

		if (!isFresh()) {
		    break;
		}

		if (confNode.isSelected() &&
                    confNode.getOutputFileObject().exists()) {
		    getTraceWriter().println(" " +
       		       confNode.getOutputFileObject().getAbsolutePath());
		}
	    }
	}

      }

    /**
     */
    public void addNodesToProject() {
	int eCount = 0;
        int totalCount = getNodes().length;
        int selectCount = 0;

	for (int i = 0; i < totalCount; i++) {
	    if (getNodes()[i].isSelected() &&
                getNodes()[i].getException() != null) {
		eCount++;
	    }
	}

	for (int i = 0; i < totalCount; i++) {
	  if (getNodes()[i].isSelected()) {
	    selectCount++;
          }
        }

	if ( eCount < selectCount ) {
	    for (int i = 0; i < totalCount; i++) {
                OtterConfFileNode confNode = (OtterConfFileNode) getNodes()[i];

		if (!isFresh()) {
		    break;
		}

		if (confNode.isSelected() &&
                    confNode.getOutputFileObject().exists()) {
                    addToOutputFolder(confNode);
		}
	    }
	}

      }


  private void addToOutputFolder(OtterConfFileNode confNode) {
    OtterNodeFactory factory      = confNode.getProject().getNodeFactory();
    OtterFolderNode  outputFolder = factory.createFolderNode(
      confNode.getProject(), confNode.getProject(), "output");
    factory.createTextFileNode(
        confNode.getProject(),
        outputFolder,
        confNode.getOutputFileObject().getAbsolutePath());
  }

  private void processNode(OtterConfFileNode confNode) {
    ConfigFile cf = new ConfigFile(confNode );
    try {
      cf.backupOutFile();
      cf.deleteOutFile();
      cf.copyInFileToOutFile();
      cf.processOutFile();
    } catch (java.io.FileNotFoundException e) {
      confNode.setException(e);
    } catch (java.io.IOException e) {
      confNode.setException(e);
    }

  }
}

class ConfigFile {
  private File       inFile    = null;
  private File       outFile   = null;
  private String[][] confTable = new String[0][0];

  protected ConfigFile(OtterConfFileNode confNode) {
    OtterProject project = confNode.getProject();
    String[][] rawTable  = project.getConfTable();
    inFile    = new File(confNode.getFilename());
    outFile   = confNode.getOutputFileObject();
    confTable = new String[rawTable.length][2];
    for (int i = 0 ; i < rawTable.length ; i++ ) {
       confTable[i][0] = rawTable[i][0];
       confTable[i][1] =PropUtil.expandPathRelativeToProject(
              project, rawTable[i][1]);
    }

    // make any needed directories.
    File file = new File(confNode.getProject().getConfOutputDirectory());
    file.mkdirs();
  }

  protected void backupOutFile()
     throws java.io.FileNotFoundException,
            java.io.IOException {
    if (outFile.exists()) {
      FileUtil.copyFile(outFile,
            new File(outFile.getAbsolutePath() + ".bak"));
    }
  }

  protected void deleteOutFile() {
    if (outFile.exists()) {
      outFile.delete();
    }

  }

  protected void copyInFileToOutFile()
     throws java.io.FileNotFoundException,
             java.io.IOException {
    FileUtil.copyFile(inFile, outFile);
  }

  protected void processOutFile() {
    String[] find    = new String[confTable.length];
    String[] replace = new String[confTable.length];
    for (int i = 0 ; i < confTable.length ; i++) {
      find[i]    = confTable[i][0];
      replace[i] = confTable[i][1];
    }
    searchAndReplace(outFile.getAbsolutePath(), find, replace);
  }

   private void searchAndReplace(String filename,
                   String[] find,
                   String[] replace) {
    BufferedReader  in = null;
    PrintWriter    out = null;
    File file = new File(filename);
    File temp = null;
    String prefix = null;
    String suffix = null;
    try {
      // Java 2
      // temp = File.createTempFile("kelp",".tmp", new File(file.getParent()));
      temp = FileUtil.createTempFile("kelp",".tmp", new File(file.getParent()));
      String tempName = temp.getAbsolutePath();
      temp.delete();
      temp = null;
      file.renameTo(new File(tempName));
      file = null;
      temp = new File(tempName);
      in = new BufferedReader(new FileReader(temp));
      out = new PrintWriter(new FileWriter(new File(filename)));
      String line = in.readLine();
      while (line != null) {
        for (int i = 0 ; i < find.length; i++) {
 	    int indexOf = line.indexOf(find[i]);
 	    if (indexOf != -1) {
              prefix = line.substring(0,indexOf);
              suffix = line.substring(indexOf + find[i].length());
              line = transformFileValues(prefix, replace[i], suffix);
	    }
        }
        out.println(line);
        line = in.readLine();
      }
      in.close();
      out.close();
    } catch (java.io.IOException e) {
      e.printStackTrace();
    }
    temp.delete();
    in   = null;
    out  = null;
    file = null;
    temp = null;
  }

    private String transformFileValues(String prefix, String replacement, String suffix) {
      // Quote and use unix style separators
      // to support long file names on Windows.
     String line = prefix + replacement + suffix;
     String value = replacement + suffix;
     File file;
      if (prefix.trim().endsWith("=")) {
        file = new File(replacement);
        file = new File(file.getParent());
        file = new File(file.getParent());
        if (file.exists() && file.isDirectory()) {
          value = value.replace('\\','/');
          value = "\"" + value + "\"";
        }
        line = prefix + value;
      }

      return line;
  }
}


class StartMultiServer {
  private OtterProject project = null;
  private File directory;
  private File file = null;

  protected StartMultiServer(OtterProject p) {
    project = p;
  }

  protected File getDirectory() {
    if (directory == null) {
       String[] paths = project.getSourcePathArray();
       directory = new File(paths[0]);
    }
    return directory;
  }

  protected void setDirectory(File d) {
    if (d != null) {
      directory = d;
    }
  }

  protected File getFile() {
    String filename = "StartMultiServer.java";
    file = new File(getDirectory(), filename);
    return file;
  }

    /**
     * Write a StartMultisServer.java file for launching and stopping MultiServer
     * with a simple graphical interface. This is useful in environments such as
     * the Win32 version of JBuilder 3 where you cannot run an arbitrary class
     * from a project.
     *
     * @throws IOException
     */
    public void create() throws java.io.IOException {
       if ((! getFile().exists()) ||
            project.isConfOverwriteSelected()) {
	PrintWriter out = new PrintWriter(new FileWriter(getFile()));
	out.println("");
	out.println("import java.awt.*;");
	out.println("import java.awt.event.*;");
	out.println("");
	out.println("public class StartMultiServer extends Frame {");
	out.println("  Button button = new Button();");
	out.println("");
	out.println("  public static void main(String[] args) {");
	out.println("    if (args == null || args.length < 1) {");
	out.println("      args = new String[1];");
        out.println("      args[0] = \"" +
            doubleEscape(project.getConfStartupConf())
              + "\";");
	out.println("     }");
	out.println("    " +  KelpVersion.getMultiServerRunClass() + ".main(args);");
	out.println("    StartMultiServer frame = new StartMultiServer();");
   	out.println("    frame.resize(200,100);");
   	out.println("    frame.setLocation(new Point(200, 200));");
	out.println("    frame.show();");
   	out.println("    frame.setLocation(new Point(200, 200)); // reset for Linux AWT");
	out.println("  }");
	out.println("");
	out.println("    public StartMultiServer() {");
	out.println("      button.setLabel(\"Shutdown MultiServer\");");
	out.println("      button.addActionListener(new ActionListener() {");
	out.println("        public void actionPerformed(ActionEvent e) {");
	out.println("         System.exit(0);");
	out.println("        }");
	out.println("      });");
	out.println("      add(button);");
	out.println("      enableEvents(java.awt.AWTEvent.WINDOW_EVENT_MASK);");
	out.println("      setTitle(\"MultiServer\");");
	out.println("    }");
	out.println("");
	out.println("  protected void processWindowEvent(java.awt.event.WindowEvent e) {");
	out.println("    super.processWindowEvent(e);");
	out.println("    if (e.getID() == java.awt.event.WindowEvent.WINDOW_CLOSING) {");
	out.println("      System.exit(0);");
	out.println("    }");
	out.println("  }");
	out.println("");
	out.println("}");
	out.println("");
	out.flush();
	out.close();
       }
    }

    private String doubleEscape(String raw) {
      StringBuffer doubled = new StringBuffer();
      String in = new String(raw);
      int index = in.indexOf("\\");
      while (index > -1) {
        doubled.append(in.substring(0,index));
        doubled.append("\\\\");
        if (index == in.lastIndexOf("\\")) {
          if (! in.endsWith("\\")) {
            doubled.append(in.substring(index + 1));
          }
          in = "";
        } else {
          in = in.substring(index + 1);
        }
        index = in.indexOf("\\");
      }
      if (doubled.toString().trim().length() == 0) {
        // Should not be any "\" on Linux so
        // no need to double escape.
        doubled.append(raw);
      }
      return doubled.toString();
    }



}