/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: StartupPropertyPanel.java,v 1.1.2.5 2000/04/04 08:29:59 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.common.wizard.conf;

import org.enhydra.devsys.swing.GridBagConstraintsX;
import org.enhydra.devsys.swing.ExtensionFilter;
import org.enhydra.ide.jbuilder.common.node.OtterConfFileNode;
import org.enhydra.ide.jbuilder.common.node.OtterNode;
import org.enhydra.ide.jbuilder.common.node.OtterProject;

import java.awt.Dimension;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.Beans;
import java.io.File;

import javax.swing.BorderFactory;
import javax.swing.JFileChooser;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.border.TitledBorder;


public class StartupPropertyPanel extends JPanel {
  private OtterNode node;
  private GridBagLayout layoutMain;
  private JCheckBox checkConfigure;
  private JCheckBox checkRunClass;
  private JCheckBox checkCreateJava;
  private JPanel panelConfigFile;
  private JTextField textConfigFile;
  private GridBagLayout layoutConfigFile;
  private JButton buttonSet;
  private TitledBorder borderFile;
  private LocalButtonListener buttonListener = null;

  public StartupPropertyPanel() {
    try {
      jbInit();
      pmInit();
    }
    catch(Exception e) {
      e.printStackTrace();
    }
  }

  public OtterNode getNode() {
    return node;
  }

  public void setNode(OtterNode n) {
    node = n;
  }

  private void pmInit() {
	buttonListener = new LocalButtonListener();
	buttonSet.addActionListener(buttonListener);
  }


  private void jbInit() throws Exception {
    checkRunClass = (JCheckBox) Beans.instantiate(getClass().getClassLoader(), JCheckBox.class.getName());
    checkCreateJava = (JCheckBox) Beans.instantiate(getClass().getClassLoader(), JCheckBox.class.getName());
    panelConfigFile = (JPanel) Beans.instantiate(getClass().getClassLoader(), JPanel.class.getName());
    textConfigFile = (JTextField) Beans.instantiate(getClass().getClassLoader(), JTextField.class.getName());
    layoutConfigFile = (GridBagLayout) Beans.instantiate(getClass().getClassLoader(), GridBagLayout.class.getName());
    buttonSet = (JButton) Beans.instantiate(getClass().getClassLoader(), JButton.class.getName());
    checkConfigure = (JCheckBox) Beans.instantiate(getClass().getClassLoader(), JCheckBox.class.getName());
    layoutMain = (GridBagLayout) Beans.instantiate(getClass().getClassLoader(), GridBagLayout.class.getName());

     borderFile = BorderFactory.createTitledBorder("MultiServer Configuration File");

    checkConfigure.setText("Configure MultiServer startup");
    checkConfigure.addActionListener(new java.awt.event.ActionListener() {

      public void actionPerformed(ActionEvent e) {
        enableUI(checkConfigure.isSelected());
      }
    });

    checkRunClass.setText("Set MultiServer as main class for project run");
    checkRunClass.setActionCommand("Set MultiServer as main class for project run");
    checkCreateJava.setText("Create StartMultiserver.java");
    textConfigFile.setText("jTextField1");
    textConfigFile.setMinimumSize(new Dimension(100, 21));
    textConfigFile.setPreferredSize(new Dimension(100, 21));
    textConfigFile.setEditable(true);

    panelConfigFile.setLayout(layoutConfigFile);
    panelConfigFile.setBorder(borderFile);
    buttonSet.setActionCommand("buttonSet");
    buttonSet.setText("Set...");
    panelConfigFile.add(textConfigFile, new GridBagConstraintsX(0, 0, 1, 1, 1.0, 0.0
            ,GridBagConstraintsX.WEST, GridBagConstraintsX.HORIZONTAL, new Insets(5, 5, 5, 5), 150, 0));
    panelConfigFile.add(buttonSet, new GridBagConstraintsX(1, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraintsX.CENTER, GridBagConstraintsX.NONE, new Insets(5, 5, 5, 5), 0, 0));
    this.setLayout(layoutMain);
    this.add(checkConfigure, new GridBagConstraintsX(0, 0, 3, 1, 0.0, 0.0
            ,GridBagConstraintsX.WEST, GridBagConstraintsX.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    this.add(checkRunClass, new GridBagConstraintsX(0, 1, 3, 1, 0.0, 0.0
            ,GridBagConstraintsX.SOUTHWEST, GridBagConstraintsX.HORIZONTAL, new Insets(5, 30, 5, 5), 0, 0));
    this.add(checkCreateJava, new GridBagConstraintsX(0, 2, 3, 1, 0.0, 0.0
            ,GridBagConstraintsX.WEST, GridBagConstraintsX.HORIZONTAL, new Insets(5, 30, 5, 5), 0, 0));
    this.add(panelConfigFile, new GridBagConstraintsX(0, 3, 1, 1, 0.0, 0.0
            ,GridBagConstraintsX.CENTER, GridBagConstraintsX.BOTH, new Insets(5, 30, 5, 5), 0, 0));
  }

  private void enableUI(boolean enable) {
    buttonSet.setEnabled(enable);
    checkCreateJava.setEnabled(enable);
    checkRunClass.setEnabled(enable);
    textConfigFile.setEnabled(enable);
  }

  public void readProperties() {
    OtterProject project = node.getProject();

    checkConfigure.setSelected(project.isConfStartupSelected());
    checkCreateJava.setSelected(project.isConfStartupJava());
    checkRunClass.setSelected(project.isConfStartupRun());
    textConfigFile.setText(project.getConfStartupConf());
    enableUI(checkConfigure.isSelected());
  }

  public void writeProperties() {
    OtterProject project = node.getProject();
    project.setConfStartupSelected(checkConfigure.isSelected());
    project.setConfStartupJava(checkCreateJava.isSelected());
    project.setConfStartupRun(checkRunClass.isSelected());
    project.setConfStartupConf(textConfigFile.getText());
  }

  private void browseForConfig() {
	JFileChooser    chooser;
	ExtensionFilter filter;
	filter = new ExtensionFilter();
	filter.addExtension("conf");
	filter.setDescriptionTitle("MultiServer Configuration");

	chooser = new JFileChooser();
	if (textConfigFile.getText().trim().length() > 0) {
         chooser.setSelectedFile(new File(textConfigFile.getText()));
        } else {
            File curDir = new File(node.getFilename());
            curDir = new File(curDir.getParent());
	    chooser.setCurrentDirectory(curDir);
	}

	chooser.setFileFilter(filter);
	chooser.setDialogTitle("Select a conf file");
	chooser.setApproveButtonText("OK");

	int v = chooser.showOpenDialog(this);

	this.requestFocus();
	buttonSet.requestFocus();

	if (v == JFileChooser.APPROVE_OPTION
		&& chooser.getSelectedFile() != null) {
	    textConfigFile.setText(chooser.getSelectedFile().getAbsolutePath());
	}

	chooser.removeAll();
	chooser = null;
    }


    class LocalButtonListener implements ActionListener {
	public void actionPerformed(ActionEvent event) {
	    Object source = event.getSource();

	    if (source == buttonSet) {
		browseForConfig();
	    }
	}

    }


}