/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: XMLCBuildTask.java,v 1.3.2.2 2000/04/08 00:49:29 pmahar Exp $
 */
package org.enhydra.ide.jbuilder.primetime.build;

import org.enhydra.ide.jbuilder.common.capture.WriteEvent;
import org.enhydra.ide.jbuilder.common.capture.WriteListener;
import org.enhydra.ide.jbuilder.common.node.OtterXMLCNode;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import org.enhydra.ide.jbuilder.primetime.node.PrimeProject;
import org.enhydra.ide.jbuilder.common.wizard.xmlc.XMLCBuildThread;
import com.borland.primetime.build.*;
import com.borland.primetime.node.*;
import com.borland.jbuilder.node.*;
import com.borland.jbuilder.build.*;
import java.util.*;

/**
 * BuildTask implementation for calling XMLC.
 *
 */
public class XMLCBuildTask implements BuildTask, WriteListener {
    public static final Object SHARED_KEY = new Object();
    private BuildProcess       buildProcess;
    private Vector	       nodeVector = new Vector();
    private Vector	       writeListeners = new Vector();
    private XMLCBuildThread    buildThread;

    public XMLCBuildTask() {}

    /**
     * Generate the DOM class using XMLC.
     */
    public boolean build(BuildProcess buildProcess, Project project,
			 boolean rebuild) {
	this.buildProcess = buildProcess;

	OtterProject    otterProject = new PrimeProject((JBProject) project);
	int		nodeCount = nodeVector.size();
        int             compileCount = nodeCount;
        OtterXMLCNode   current = null;

        // remove upToDate nodes from vector if not a rebuild.
        if (! rebuild) {
   	  for (int i = 0; i < nodeCount; i++) {
	    current = (OtterXMLCNode) nodeVector.elementAt(i);
            if (upToDate(current)) {
               nodeVector.setElementAt(new Object(), i);
               compileCount--;
            }
          }
	}

	OtterXMLCNode[] nodes = new OtterXMLCNode[compileCount];

        int j = 0;
	for (int i = 0; i < nodeCount && j < compileCount ; i++ ) {
            if (nodeVector.elementAt(i) instanceof OtterXMLCNode) {
  	      nodes[j] = (OtterXMLCNode) nodeVector.elementAt(i);
  	      j++;
            }
	}

	WriteListener[] w = new WriteListener[1];

	w[0] = this;

	buildProcess.fireBuildStatus("Generating DOM classes with Enhydra XMLC",
				     true);

	buildThread = new XMLCBuildThread(w, true);

	buildThread.setProject(otterProject);
	buildThread.setNodes(nodes);
	buildThread.setPrintProgress(false);
	buildThread.runInCurrentThread();

	for (int i = 0; i < compileCount; i++) {
	    nodes[i].replaceGeneratedSource();
	}

	return true;
    }

    /**
     * Build messages.
     *
     */
    public void onWrite(WriteEvent e) {
	if (buildProcess != null) {
	    buildProcess.fireBuildMessage(e.getString(), e.getString());
	}
    }

    /**
     * Collect list of nodes to build.
     *
     */
    public void addNode(OtterXMLCNode n) {
	nodeVector.addElement(n);
    }

 /**
     * Check if node up to date.
     *
     */
    private boolean upToDate(OtterXMLCNode xmlcNode) {
	boolean built = false;
        HTMLFileNode htmlNode = (HTMLFileNode) xmlcNode.getNativeNode();

	if (htmlNode.isModified()) {
	    try {
		htmlNode.save();
	    } catch (Exception e) {
		e.printStackTrace();
	    }
	} else if (!xmlcNode.getClassFile().exists()) {}
	else if (xmlcNode.getClassFile().lastModified()
		 > htmlNode.getUrl().getFileObject().lastModified()) {
	    built = true;
	}

	return built;
    }


}




