/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: PrimeHTMLFileNode.java,v 1.3.2.3 2000/04/10 05:58:38 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.primetime.node;

import org.enhydra.ide.jbuilder.common.PropUtil;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import org.enhydra.ide.jbuilder.common.node.OtterNode;
import org.enhydra.ide.jbuilder.common.node.OtterHTMLFileNode;
import org.enhydra.ide.jbuilder.common.node.OtterSelectionNode;
import com.borland.jbuilder.node.HTMLFileNode;
import com.borland.primetime.node.Project;
import com.borland.primetime.node.Node;
import com.borland.primetime.vfs.Url;
import com.borland.primetime.node.DuplicateNodeException;
import java.io.File;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class PrimeHTMLFileNode extends PrimeNode
    implements OtterHTMLFileNode {

    private String javacDirectory;
    private Exception exception = null;

    public PrimeHTMLFileNode(HTMLFileNode n) {
        super(n);
    }

    /**
     * Constructor declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @see
     */
    public PrimeHTMLFileNode(OtterProject otterProject, OtterNode otterNode,
			     String file) {
	Project      nativeProject = null;
	Node	     nativeNode = null;
	HTMLFileNode nativeHTMLFile = null;

	if (otterProject.getNativeProject() instanceof Project) {
	    nativeProject = (Project) otterProject.getNativeProject();
	}

	if (otterNode.getNativeNode() instanceof Node) {
	    nativeNode = (Node) otterNode.getNativeNode();
	}

	if (nativeProject != null && nativeNode != null) {
	    try {
		nativeHTMLFile = new HTMLFileNode(nativeProject, nativeNode,
						  new Url(new File(file)));
	    } catch (DuplicateNodeException e) {
		System.err.println(e);
		System.err.println(file + " already in project.");
	    }
	}

	setNativeNode(nativeHTMLFile);
    }



  public boolean isSelected() {
   String  in = getProperty(OtterSelectionNode.SELECTED);
   return PropUtil.stringToBoolean(in, false);
  }

  public void setSelected(boolean b) {
	setProperty(OtterSelectionNode.SELECTED,
	   PropUtil.booleanToString(b));
  }

  public String getJavacDirectory() {
    return javacDirectory;
  }

  public void setJavacDirectory(String s) {
    javacDirectory = s;
  }


    /**
     * Save Exception information for reporting. This lets exceptions from
     * multiple nodes to be reported in a batch.
     *
     * @param e
     * An exception that occured while invoking XMLC.
     */
    public void setException(Exception e) {
	exception = e;
    }

    /**
     * Get an exception that occured when invoking XMLC. Null if the node
     * has not been compiled or was compiled without error.
     */
    public Exception getException() {
	return exception;
    }


  public void preCompile() {
    if (getNativeNode() instanceof HTMLFileNode) {
       HTMLFileNode nativeNode = (HTMLFileNode) getNativeNode();
       if (nativeNode.isModified()) {
         try {
           nativeNode.save();
         } catch (com.borland.primetime.vfs.InvalidUrlException e) {
           e.printStackTrace();
         } catch (java.io.IOException e) {
           e.printStackTrace();
         }

      }
    }
     // nothing extra to do for Primetime.
  }


}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

