/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: PrimeNode.java,v 1.5.2.1 2000/03/30 02:50:02 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.primetime.node;

import org.enhydra.ide.jbuilder.common.node.OtterNode;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import com.borland.jbuilder.node.JBProject;
import com.borland.primetime.node.FileNode;
import com.borland.primetime.node.Node;
import com.borland.primetime.vfs.Url;
import java.io.File;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class PrimeNode implements OtterNode {
    private Node nativeNode = null;

    /**
     * Constructor declaration
     *
     *
     * @see
     */
    public PrimeNode() {}

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public char getFileSeparatorChar() {
	return '/';
    }

    /**
     * Constructor declaration
     *
     *
     * @param node
     *
     * @see
     */
    public PrimeNode(Node n) {
	nativeNode = n;
    }

    public OtterProject getProject() {
      return (new PrimeProject((JBProject)nativeNode.getProject()));
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getFilename() {
	String out = null;

	if (nativeNode != null) {
	    if (nativeNode instanceof FileNode) {
		FileNode fileNode;

		fileNode = (FileNode) nativeNode;
		out = fileNode.getUrl().getFile();
	    }
	}

	return out;
    }

    public String getXMLCOptionFilename() {
      String opFilename = getProperty(OtterNode.XMLC_OPTION_FILENAME);
      File workFile;
      if (opFilename == null) {
        opFilename = new String();
      } else {
        workFile = new File(opFilename);
        if (! workFile.exists()) {
          workFile = new File(getProject().getFilename());
          opFilename = workFile.getParent() +
                        File.separator + opFilename;
          workFile = new File(opFilename);
          if (! workFile.exists()) {
            opFilename = new String();
          }
        }
      }
      return opFilename;
    }

    public void setXMLCOptionFilename(String n) {
    // make this relative to project location
      File   workFile = new File(getProject().getFilename());
      String projDir  = workFile.getParent();
      workFile = new File(n);
      String opFilename = workFile.getAbsolutePath();
      if (opFilename.startsWith(projDir)) {
        opFilename = opFilename.substring(projDir.length()+1);
      }
      setProperty(OtterNode.XMLC_OPTION_FILENAME, opFilename);
    }

    public String getXMLCParameters() {
      return getProperty(OtterNode.XMLC_PARAMETERS);
    }

    public void setXMLCParameters(String p) {
      setProperty(OtterNode.XMLC_PARAMETERS, p);
    }



    /**
     * Method declaration
     *
     *
     * @param property
     *
     * @return
     *
     * @see
     */
    public String getProperty(String property) {
	String out = null;

	if (nativeNode != null) {
	    out = nativeNode.getProperty(property);
	}

	return out;
    }

    /**
     * Method declaration
     *
     *
     * @param property
     * @param value
     *
     * @see
     */
    public void setProperty(String property, String value) {
	if (nativeNode != null) {
	    nativeNode.setProperty(property, value);
	}
    }

    public void setProperty(String property, int i) {
        String value = Integer.toString(i);
	setProperty(property, value);
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public Object getNativeNode() {
	return nativeNode;
    }

    /**
     * Method declaration
     *
     *
     * @param n
     *
     * @see
     */
    public void setNativeNode(Object n) {
	nativeNode = (Node) n;
    }

}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

