/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: PrimeNodeFactory.java,v 1.3.2.2 2000/03/21 09:47:48 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.primetime.node;

import org.enhydra.ide.jbuilder.common.node.OtterNode;
import org.enhydra.ide.jbuilder.common.node.OtterNodeFactory;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import org.enhydra.ide.jbuilder.common.node.OtterConfFileNode;
import org.enhydra.ide.jbuilder.common.node.OtterFolderNode;
import org.enhydra.ide.jbuilder.common.node.OtterHTMLFileNode;
import org.enhydra.ide.jbuilder.common.node.OtterImageFileNode;
import org.enhydra.ide.jbuilder.common.node.OtterJavaFileNode;
import org.enhydra.ide.jbuilder.common.node.OtterTextFileNode;

import com.borland.primetime.node.Node;
import com.borland.primetime.node.FileNode;
import com.borland.primetime.node.FolderNode;
import com.borland.jbuilder.node.JBProject;

import java.io.File;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class PrimeNodeFactory implements OtterNodeFactory {

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param name
     *
     * @return
     *
     * @see
     */
    public OtterFolderNode createFolderNode(OtterProject otterProject,
					    OtterNode otterNode,
					    String name) {
        OtterFolderNode folder = null;
        FolderNode nativeFolder = null;

        // check if exists
        JBProject nativeProject = (JBProject) otterProject.getNativeProject();
        Node[] nativeChild = nativeProject.getChildren();
        for (int i = 0 ; i  < nativeChild.length ; i++ ) {
          if (nativeChild[i] instanceof FolderNode) {
             nativeFolder = (FolderNode) nativeChild[i];
             if (nativeFolder.getName().trim().equalsIgnoreCase(name.trim())) {
               folder = new PrimeFolderNode(nativeFolder);
             }
          }
        }
	if (folder == null) {
         folder = new PrimeFolderNode(otterProject, otterNode,
		name);
        }
	return folder;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterJavaFileNode createJavaFileNode(OtterProject otterProject,
						OtterNode otterNode,
						String file) {
	OtterJavaFileNode javaFile = new PrimeJavaFileNode(otterProject,
		otterNode, file);

	return javaFile;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterHTMLFileNode createHTMLFileNode(OtterProject otterProject,
						OtterNode otterNode,
						String file) {
	OtterHTMLFileNode html = new PrimeHTMLFileNode(otterProject,
		otterNode, file);

	return html;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterImageFileNode createImageFileNode(OtterProject otterProject,
	    OtterNode otterNode, String file) {
	OtterImageFileNode image = new PrimeImageFileNode(otterProject,
		otterNode, file);

	return image;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterTextFileNode createTextFileNode(OtterProject otterProject,
						OtterNode otterNode,
						String file) {
	OtterTextFileNode text = new PrimeTextFileNode(otterProject,
		otterNode, file);

	return text;
    }

    public OtterConfFileNode createConfFileNode(OtterProject otterProject,
						OtterNode otterNode,
						String file) {
	OtterConfFileNode conf = new PrimeConfFileNode(otterProject,
		otterNode, file);

	return conf;
    }

    public OtterJavaFileNode replaceGeneratedSource(
           OtterProject project,
           OtterNode node, String file) {
       // Remove previously generated sources and then add
       JBProject nativeProject = (JBProject) project.getNativeProject();
       FileNode nativeNode = (FileNode) node.getNativeNode();
       Node[] child = nativeNode.getChildren();
       FileNode fn = null;
       File addFile = new File(file);
       boolean keep = false;
       for (int i = 0 ; i < child.length ; i++ ) {
         if (child[i] instanceof FileNode) {
           fn = (FileNode) child[i];
           if (fn.getUrl().getFileObject().getAbsolutePath().equals(addFile.getAbsolutePath())) {
             keep = true;
           } else {
             fn.getUrl().getFileObject().delete();
           }
         }
         if (! keep) {
           child[i].setParent(null);
        }
       }
       try {
         nativeNode.save();
       } catch (Exception e) {
         e.printStackTrace();
       }
       nativeNode.check();
       nativeProject.fireChildrenChanged(nativeNode);
       nativeProject.check();
       try {
         nativeProject.save();
       } catch (Exception e) {
         e.printStackTrace();
       }
       return createJavaFileNode(project, node, file);
    }


}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

