/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: XMLCProperties.java,v 1.1.2.1 2000/04/01 00:14:40 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.primetime.properties;

import org.enhydra.devsys.swing.SwingUtil;
import org.enhydra.ide.jbuilder.primetime.node.PrimeHTMLFileNode;
import org.enhydra.ide.jbuilder.common.node.OtterXMLCNode;

import com.borland.jbuilder.node.HTMLFileNode;
import com.borland.primetime.ide.Browser;
import com.borland.primetime.node.Node;
import com.borland.primetime.node.Project;
import com.borland.primetime.properties.PropertyPageFactory;
import com.borland.primetime.properties.PropertyPage;
import com.borland.primetime.properties.PropertyManager;
import com.borland.primetime.properties.PropertyGroup;

public class XMLCProperties implements PropertyGroup {

  public static final String GENERATE_CLASS = "Generate";

  public XMLCProperties() {
  }


  /**
   * Initialize this OpenTool
   */
  public static void initOpenTool(byte majorVersion, byte minorVersion) {
	PropertyManager.registerPropertyGroup(new XMLCProperties());
  }

  /**
   * Returns a PropertyPageFactory for the project or for an
   * HTMLFileNode. Null if topic is something else.
   *
   * TODO: ?? Add XMLFileNode ??
   */
  public PropertyPageFactory getPageFactory(final Object topic) {
    PropertyPageFactory factory = null;
    if (topic instanceof HTMLFileNode) {
      Project project = ((Node)topic).getProject();
      if (project != null) {
        // Node property page to set your XMLC properties
        factory = (new PropertyPageFactory("Enhydra XMLC") {
          public PropertyPage createPropertyPage() {
            SwingUtil.setDialogOwner(Browser.getActiveBrowser());
            return new XMLCNodePropertyPage(topic);
          }
        });
      }
    } else if (topic instanceof Project) {
        // Project property page to set your XMLC properties
        factory = (new PropertyPageFactory("Enhydra XMLC") {
          public PropertyPage createPropertyPage() {
            SwingUtil.setDialogOwner(Browser.getActiveBrowser());
            return new XMLCProjectPropertyPage(topic);
          }
        });
    }
    return factory;
  }

  public void initializeProperties() {
  }
}