/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: ConfWizard.java,v 1.1.2.4 2000/04/01 00:14:43 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.primetime.wizard.conf;

import org.enhydra.devsys.swing.SwingUtil;
import org.enhydra.devsys.swing.IconSet;
import org.enhydra.ide.jbuilder.primetime.wizard.AbstractBasicWizard;
import org.enhydra.ide.jbuilder.primetime.node.PrimeProject;
import org.enhydra.ide.jbuilder.primetime.node.PrimeConfFileNode;
import org.enhydra.ide.jbuilder.common.wizard.conf.ConfBuildDialog;
import org.enhydra.ide.jbuilder.common.node.OtterConfFileNode;

import com.borland.jbuilder.node.JBProject;
import com.borland.primetime.node.FileNode;
import com.borland.primetime.node.TextFileNode;
import com.borland.primetime.ide.Browser;
import com.borland.primetime.ide.BrowserListener;
import com.borland.primetime.ide.NodeViewer;
import com.borland.primetime.node.Node;
import com.borland.primetime.node.Project;
import com.borland.primetime.wizard.Wizard;
import com.borland.primetime.wizard.WizardAction;
import com.borland.primetime.wizard.WizardHost;
import com.borland.primetime.wizard.WizardManager;
import com.borland.primetime.wizard.WizardPage;
import com.borland.primetime.util.VetoException;
import com.borland.primetime.vfs.InvalidUrlException;
import javax.swing.JOptionPane;
import java.io.File;
import java.util.Vector;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class ConfWizard extends AbstractBasicWizard {

    public static WizardAction action =  new ConfWizardAction();
    /**
     * Method declaration
     *
     *
     * @param majorVersion
     * @param minorVersion
     *
     * @see
     */
    public static void initOpenTool(byte majorVersion, byte minorVersion) {
	WizardManager.registerWizardAction(action);
        Browser.addStaticBrowserListener(browserListener);
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public static String getName() {
	return "Enhydra Configure";
    }

    /**
     * Class declaration
     *
     *
     * @author
     * @version %I%, %G%
     */
    static class ConfWizardAction extends WizardAction {

	/**
	 * Constructor declaration
	 *
	 *
	 * @see
	 */
	public ConfWizardAction() {
	    super(getName() + "...", 'X',
		  "Process conf.in files and copy them to an output directory",
                  IconSet.getSmallIcon(),
                  IconSet.getLargeIcon(),
		  false);
        }

	/**
	 * Method declaration
	 *
	 *
	 * @return
	 *
	 * @see
	 */
	protected Wizard createWizard() {
	    return new ConfWizard();
	}

	/**
	 * Method declaration
	 *
	 *
	 * @param source
	 *
	 * @see
	 */
	public void update(Object source) {
	    setEnabled(AbstractBasicWizard.enableMenu);
	}

    }

    ;

    /**
     * Method declaration
     *
     *
     * @param host
     *
     * @see
     */
    public synchronized void invoke(WizardHost host) {
	PrimeProject         primeProject = null;
	OtterConfFileNode[]  confNodes    = null;
	ConfBuildDialog dlg = null;
	setNativeProject(
          (JBProject) host.getBrowser().getProjectView().getActiveProject());

	if (getNativeProject() != null) {
	    try {
		getNativeProject().save();
	    } catch (InvalidUrlException e) {
		e.printStackTrace();
	    } catch (java.io.IOException e) {
		e.printStackTrace();
	    }

	    primeProject = new PrimeProject(getNativeProject());
	}
	if (isEnhydraAvailable(primeProject.getClassPath())) {
            SwingUtil.setDialogOwner(host.getBrowser());
	    dlg = new ConfBuildDialog(host.getDialogParent(), getName(), true);
	    readNodes(getNativeProject());
	    confNodes = new OtterConfFileNode[getSourceVector().size()];

	    for (int i = 0; i < confNodes.length; i++) {
		confNodes[i] = (OtterConfFileNode) getSourceVector().elementAt(i);
	    }

	    dlg.setProject(primeProject);
	    dlg.setNodes(confNodes);
	    dlg.show();
	}
    }

    // recursively read through nodes.

    /**
     * Method declaration
     *
     *
     * @param container
     *
     * @see
     */
    private void readNodes(Node container) {
	String        filename = null;
	OtterConfFileNode confNode = null;
	Node[]        nativeNodes = container.getChildren();
	FileNode      fileNode = null;
	File	      current = null;
	String        projectPage = getNativeProject().getUrl().getFile();

	for (int i = 0; i < nativeNodes.length; i++) {
	    if (nativeNodes[i] instanceof FileNode) {
		fileNode = (FileNode) nativeNodes[i];
		filename = fileNode.getUrl().getFile();
		current = new File(filename);

		if (current.exists() &&
		    current.getAbsolutePath().toLowerCase().endsWith(".conf.in")) {
          	    PrimeConfFileNode primeNode = null;
                    confNode = new PrimeConfFileNode((TextFileNode)fileNode);
  	            getSourceVector().addElement(confNode);
		}
	    }

	    readNodes(nativeNodes[i]);    // recrusive folder read.
	}
    }

}
