/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: EnhydraAppWizard.java,v 1.5.2.3 2000/04/01 00:14:44 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.primetime.wizard.newapp;

import org.enhydra.devsys.swing.SwingUtil;
import org.enhydra.devsys.swing.IconSet;
import org.enhydra.devsys.wizard.newapp.PropertyException;
import org.enhydra.ide.KelpVersion;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import org.enhydra.ide.jbuilder.primetime.node.PrimeProject;
import org.enhydra.ide.jbuilder.common.wizard.newapp.EnhydraAppMaker;
import org.enhydra.ide.jbuilder.primetime.node.PrimeProject;
import org.enhydra.ide.jbuilder.common.node.OtterFolderNode;

import com.lutris.devsys.newApp.NewAppException;

import com.borland.primetime.wizard.BasicWizard;
import com.borland.primetime.wizard.Wizard;
import com.borland.primetime.wizard.WizardAction;
import com.borland.primetime.wizard.WizardDialog;
import com.borland.primetime.wizard.WizardHost;
import com.borland.primetime.wizard.WizardManager;
import com.borland.primetime.wizard.WizardPage;
import com.borland.primetime.util.VetoException;
import com.borland.primetime.ide.BrowserIcons;
import com.borland.primetime.vfs.Url;
import com.borland.primetime.node.Project;
import com.borland.primetime.node.DuplicateNodeException;
import com.borland.primetime.help.ZipHelpTopic;
import com.borland.jbuilder.wizard.project.JBProjectWizard;
import com.borland.jbuilder.node.JBProject;
import com.borland.jbuilder.build.JavaBuildPropertyGroup;
import java.io.File;
import java.util.Properties;
import javax.swing.JOptionPane;
import javax.swing.ImageIcon;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class EnhydraAppWizard extends BasicWizard {
    private EnhydraAppMaker    appMaker = new EnhydraAppMaker();
    private EnhydraAppPage     page = new EnhydraAppPage();
    private JBProject	       nativeProject;
    private final String HELP_TOPIC = "file:../jb-kelp/doc/developer/jb-kelp.html#appwizard";


    public static WizardAction WIZARD_EnhydraAppWizard =
       new WizardAction(EnhydraAppMaker.getGalleryName(), 'X',
                        "Creates a new Enhydra XMLC Application",
            IconSet.getSmallIcon(),
            IconSet.getLargeIcon(),
            true, "Enhydra") {

	/**
	 * Method declaration
	 *
	 *
	 * @return
	 *
	 * @see
	 */
	protected Wizard createWizard() {
           EnhydraAppWizard wiz = new EnhydraAppWizard();
	   return wiz;
	}

	/**
	 * Method declaration
	 *
	 *
	 * @param source
	 *
	 * @see
	 */
	public void update(Object source) {
	    setEnabled(true);
	}

    };

    /**
     * Method declaration
     *
     *
     * @param majorVersion
     * @param minorVersion
     *
     * @see
     */
    public static void initOpenTool(byte majorVersion, byte minorVersion) {
	WizardManager.registerWizardAction(WIZARD_EnhydraAppWizard);
    }

    public void help(WizardPage currentPage,
                     WizardHost host) {
      ZipHelpTopic t = new ZipHelpTopic( null, HELP_TOPIC );
      t.show(host.getDialogParent());
    }

    /**
     * Method declaration
     *
     * @param host
     *
     * @return
     *
     * @see
     */
    public WizardPage invokeWizard(WizardHost host) {
	WizardPage wizPage = null;
        PrimeProject primeProject = null;

	setWizardTitle(appMaker.getTitle());
	initProject(host);
        primeProject = new PrimeProject(nativeProject);
	appMaker.setProject(primeProject);

        File f = new File(primeProject.getFilename());
        appMaker.setRootDir(f.getParentFile().getParent());

        if ((nativeProject != null) && (nativeProject instanceof JBProject)) {
            SwingUtil.setDialogOwner(host.getBrowser());
	    page.setPageTitle(appMaker.getPageTitle());
	    page.setInstructions(appMaker.getInstructions());
	    appMaker.writeAppProperties(page);
	    addWizardPage(page);

	    wizPage = super.invokeWizard(host);
	}

	return wizPage;
    }

    /**
     * Method declaration
     *
     *
     * @param host
     *
     * @see
     */
    private void initProject(WizardHost host) {
	nativeProject =
	    (JBProject) host.getBrowser().getProjectView().getActiveProject();

       if ((nativeProject == null) || !(nativeProject instanceof JBProject)) {
          WizardDialog dlg = new WizardDialog(host.getBrowser(), new JBProjectWizard());
          dlg.show();
          nativeProject = (JBProject) host.getBrowser().getProjectView().getActiveProject();
       }
    }

    /**
     * Method declaration
     *
     *
     * @throws VetoException
     *
     * @see
     */
    protected void finish() throws VetoException {
	boolean continueBuild = true;
	if (nativeProject != null) {
	    appMaker.readAppProperties(page);
            try {
              appMaker.validateProperties();
            } catch (PropertyException e) {
        	JOptionPane.showMessageDialog(this.wizardHost.getDialogParent(),
					      e.getDialogMessage(),
					      appMaker.getTitle(),
					      JOptionPane.WARNING_MESSAGE);

               throw new VetoException();
            }


	    try {
		appMaker.createAppTree();
	    } catch (NewAppException e) {
		continueBuild = false;

		JOptionPane.showMessageDialog(this.wizardHost.getDialogParent(),
					      e.getMessage(),
					      "Error generating application",
					      JOptionPane.ERROR_MESSAGE);
	    }

	    if (continueBuild) {
		appMaker.createAppFiles();
                try {
                  appMaker.writeReadme(getSteps());
                } catch (java.io.IOException e) {
                  e.printStackTrace();
                }
		addAppToProject();
	    }
	}
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void addAppToProject() {
	File f;
        OtterProject otterProject = new PrimeProject(nativeProject);
        otterProject.configureRunClass();

	f = new File(appMaker.getAppDir());

	Url[] sourcePaths = {
	    new Url(f)
	};

	nativeProject.getPaths().setSourcePath(sourcePaths);

	if (!nativeProject.getPaths().putClassOnFullPath(KelpVersion.getMultiServerRunClass())) {

	    // no enhydra library
	}

	appMaker.addAppToProject();
	JavaBuildPropertyGroup.SYNC_DIR.setValue(nativeProject,
						 String.valueOf(false));
    }

    private String[] getSteps() {
      String[] steps = new String[4];
      steps[0] = "Use the XMLC Compiler Wizard to compile your html pages into DOM classes.<BR>";
      steps[1] = "Make the project to compile the java files.";
      steps[2] = "Start the MultiServer by running the project.";
      steps[3] = "From your browser enter: http:\\localhost:9000";
      return steps;
    }


}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

