/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: EnhydraAppWizard.java,v 1.7.2.5 2000/04/06 02:53:50 pmahar Exp $
 */
package org.enhydra.ide.jbuilder.win32.wizard.newapp;

import org.enhydra.devsys.swing.SwingUtil;
import org.enhydra.devsys.swing.IconSet;
import org.enhydra.devsys.wizard.common.WizardDialog;
import org.enhydra.ide.jbuilder.common.wizard.newapp.EnhydraAppMaker;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import org.enhydra.ide.jbuilder.win32.node.WinProject;
import com.borland.jbuilder.addin.Addin;
import com.borland.jbuilder.addin.Context;
import com.borland.jbuilder.addin.Container;
import com.borland.jbuilder.addin.IdeEnvironment;
import com.borland.jbuilder.addin.Wizard;
import com.borland.jbuilder.addin.Project;
import com.borland.jbuilder.addin.VersionedAddin;
import java.awt.Image;
import java.io.File;
import javax.swing.JOptionPane;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class EnhydraAppWizard implements Wizard, VersionedAddin  {
    private EnhydraAppMaker appMaker = new EnhydraAppMaker();
    private String	    imageFileName = new String();
    private Image	    bigImage;

    /**
     * Method declaration
     *
     *
     * @param ide
     *
     * @see
     */
    public void startup(IdeEnvironment ide) {
	if (imageFileName.length() > 0) {

	    // bigImage = imageImageLoader.loadFromResource(imageFileName,
	    // ide.getIdeFrame(), getClass());
	}
    }

    /**
     * For the VersionAddin Interface.
     */
    public String version() {
	return "1.1";
    }

    /**
     * Method declaration
     *
     *
     * @param ide
     * @param context
     *
     * @see
     */
    public void invoke(IdeEnvironment ide, Context context) {
	Project      nativeProject = null;

	if (context != null) {
	    nativeProject = context.getProject();

	    if (nativeProject == null  || nativeProject.getType().equals(Container.ROOT_TYPE)) {
		nativeProject = null;
		JOptionPane.showMessageDialog(ide.getIdeFrame(),
  	          "Project not found. Please create a new project before " +
                  "starting the new Enhydra Application wizard.");
	    }

	    if (nativeProject != null) {
                SwingUtil.setDialogOwner(ide.getIdeFrame());

             	OtterProject otterProject = new WinProject(nativeProject);
                otterProject.setConfStartupJava(true);
 		appMaker.setProject(otterProject);
                File file       = new File(otterProject.getFilename());
                File parentFile = new File(file.getParent()); // JDK 1.1
                appMaker.setRootDir(parentFile.getParent());
		appMaker.invokeWizard(ide.getIdeFrame());
                if (appMaker.getChoice() ==  WizardDialog.CHOICE_OK) {
                  try {
                    appMaker.writeReadme(getSteps());
		  } catch (java.io.IOException e) {
		      e.printStackTrace();
		  }
		  appMaker.addAppToProject();
		  JOptionPane.showMessageDialog(ide.getIdeFrame(),
  	           "Enhydra Application files have been added to: \n"
	            + "     " + nativeProject.getFilename()
                    + ".\n"
		    + "Refer to the Readme.html file for the steps \n "
                    + "required to compile and run your new XMLC \n"
                    + "application");
                }
	    }

	}
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String toString() {
	return getName();
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getName() {
        return EnhydraAppMaker.getGalleryName();
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getMenuLabel() {
	return null;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public Image getBigImage() {
	return IconSet.getLargeIcon().getImage();
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public Image getSmallImage() {
	return IconSet.getSmallIcon().getImage();
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public int getInfo() {
	return Wizard.REQUIRES_PROJECT | Wizard.PRODUCES_FILE;
    }

    private String[] getSteps() {
      String[] steps = new String[8];
      steps[0] = "Add <B>Enhydra</B> to the project's Java library list.<BR>";
      steps[1] = "Replace the current <i>Source Root directory</i> with " +
                 "a single path to: <BR>" +
                 "<B><code>" + appMaker.getAppDir() + "</code>/</B><BR>";
      steps[2] = "Set the <i>Output Root directory</i> to: <BR>" +
                 "<B><code>" + appMaker.getAppDir() + "\\classes</code></B><BR>";
      steps[3] = "Close and reopen your project to commit and reload all changes." +
                 "<P><I>Note: Erronious &quot;Duplicate definition&quot; errors" +
                 " may occur if you do not close and reopen the project." +
                "</I></P>";
      steps[4] = "Open the XMLC Compiler wizard and click on Compile to " +
                 "generate a DOM class from Welcome.html.<BR>";
      steps[5] = "Make the project to compile the java files.";
      steps[6] = "Run the StartMultiServer program to launch the server.<BR>";
      steps[7] = "From your browser enter: http:\\localhost:9000<BR>";
      return steps;
    }

}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

